require_relative "../../test_helper"

class ATest < MTest
  def test_a
    assert_equal 1, 2
  end
end
